@@ -3,14 +3,37 @@ use strict;
 use warnings;
 
 package CPAN::Mini;
-{
-  $CPAN::Mini::VERSION = '1.111015';
-}
-
+$CPAN::Mini::VERSION = '1.111016';
 # ABSTRACT: create a minimal mirror of CPAN
 
 ## no critic RequireCarping
 
+#pod =head1 SYNOPSIS
+#pod
+#pod (If you're not going to do something weird, you probably want to look at the
+#pod L<minicpan> command, instead.)
+#pod
+#pod   use CPAN::Mini;
+#pod
+#pod   CPAN::Mini->update_mirror(
+#pod     remote => "http://cpan.mirrors.comintern.su",
+#pod     local  => "/usr/share/mirrors/cpan",
+#pod     log_level => 'debug',
+#pod   );
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod CPAN::Mini provides a simple mechanism to build and update a minimal mirror of
+#pod the CPAN on your local disk.  It contains only those files needed to install
+#pod the newest version of every distribution.  Those files are:
+#pod
+#pod =for :list
+#pod * 01mailrc.txt.gz
+#pod * 02packages.details.txt.gz
+#pod * 03modlist.data.gz
+#pod * the last non-developer release of every dist for every author
+#pod
+#pod =cut
 
 use Carp ();
 
@@ -27,6 +50,116 @@ use LWP::UserAgent 5 ();
 
 use Compress::Zlib 1.20 ();
 
+#pod =method update_mirror
+#pod
+#pod   CPAN::Mini->update_mirror(
+#pod     remote => "http://cpan.mirrors.comintern.su",
+#pod     local  => "/usr/share/mirrors/cpan",
+#pod     force  => 0,
+#pod     log_level => 'debug',
+#pod   );
+#pod
+#pod This is the only method that need be called from outside this module.  It will
+#pod update the local mirror with the files from the remote mirror.
+#pod
+#pod If called as a class method, C<update_mirror> creates an ephemeral CPAN::Mini
+#pod object on which other methods are called.  That object is used to store mirror
+#pod location and state.
+#pod
+#pod This method returns the number of files updated.
+#pod
+#pod The following options are recognized:
+#pod
+#pod =begin :list
+#pod
+#pod * C<local>
+#pod
+#pod This is the local file path where the mirror will be written or updated.
+#pod
+#pod * C<remote>
+#pod
+#pod This is the URL of the CPAN mirror from which to work.  A reasonable default
+#pod will be picked by default.  A list of CPAN mirrors can be found at
+#pod L<http://www.cpan.org/SITES.html>
+#pod
+#pod * C<dirmode>
+#pod
+#pod Generally an octal number, this option sets the permissions of created
+#pod directories.  It defaults to 0711.
+#pod
+#pod * C<exact_mirror>
+#pod
+#pod If true, the C<files_allowed> method will allow all extra files to be mirrored.
+#pod
+#pod * C<ignore_source_control>
+#pod
+#pod If true, CPAN::Mini will not try to remove source control files during
+#pod cleanup. See C<clean_unmirrored> for details.
+#pod
+#pod * C<force>
+#pod
+#pod If true, this option will cause CPAN::Mini to read the entire module list and
+#pod update anything out of date, even if the module list itself wasn't out of date
+#pod on this run.
+#pod
+#pod * C<skip_perl>
+#pod
+#pod If true, CPAN::Mini will skip the major language distributions: perl, parrot,
+#pod and ponie.  It will also skip embperl, sybperl, bioperl, and kurila.
+#pod
+#pod * C<log_level>
+#pod
+#pod This defines the minimum level of message to log: debug, info, warn, or fatal
+#pod
+#pod * C<errors>
+#pod
+#pod If true, CPAN::Mini will warn with status messages on errors.  (default: true)
+#pod
+#pod * C<path_filters>
+#pod
+#pod This options provides a set of rules for filtering paths.  If a distribution
+#pod matches one of the rules in C<path_filters>, it will not be mirrored.  A regex
+#pod rule is matched if the path matches the regex; a code rule is matched if the
+#pod code returns 1 when the path is passed to it.  For example, the following
+#pod setting would skip all distributions from RJBS and SUNGO:
+#pod
+#pod  path_filters => [
+#pod    qr/RJBS/,
+#pod    sub { $_[0] =~ /SUNGO/ }
+#pod  ]
+#pod
+#pod * C<module_filters>
+#pod
+#pod This option provides a set of rules for filtering modules.  It behaves like
+#pod path_filters, but acts only on module names.  (Since most modules are in
+#pod distributions with more than one module, this setting will probably be less
+#pod useful than C<path_filters>.)  For example, this setting will skip any
+#pod distribution containing only modules with the word "Acme" in them:
+#pod
+#pod  module_filters => [ qr/Acme/i ]
+#pod
+#pod * C<also_mirror>
+#pod
+#pod This option should be an arrayref of extra files in the remote CPAN to mirror
+#pod locally.
+#pod
+#pod * C<skip_cleanup>
+#pod
+#pod If this option is true, CPAN::Mini will not try delete unmirrored files when it
+#pod has finished mirroring
+#pod
+#pod * C<offline>
+#pod
+#pod If offline, CPAN::Mini will not attempt to contact remote resources.
+#pod
+#pod * C<no_conn_cache>
+#pod
+#pod If true, no connection cache will be established.  This is mostly useful as a
+#pod workaround for connection cache failures.
+#pod
+#pod =end :list
+#pod
+#pod =cut
 
 sub update_mirror {
   my $self = shift;
@@ -102,8 +235,11 @@ sub _get_mirror_list {
       if (/\S/) {
         my ($header, $value) = split /:\s*/, $_, 2;
         chomp $value;
-        $file_ok = 1 if $header eq 'File'
-                    and $value eq '02packages.details.txt';
+        if ($header eq 'File'
+            and ($value eq '02packages.details.txt'
+                 or $value eq '02packages.details.txt.gz')) {
+          $file_ok = 1;
+        }
       } else {
         $inheader = 0;
       }
@@ -127,6 +263,14 @@ sub _get_mirror_list {
   return [ sort keys %mirror_list ];
 }
 
+#pod =method new
+#pod
+#pod   my $minicpan = CPAN::Mini->new;
+#pod
+#pod This method constructs a new CPAN::Mini object.  Its parameters are described
+#pod above, under C<update_mirror>.
+#pod
+#pod =cut
 
 sub new {
   my $class    = shift;
@@ -194,6 +338,13 @@ sub new {
 
 sub __lwp { $_[0]->{__lwp} }
 
+#pod =method mirror_indices
+#pod
+#pod   $minicpan->mirror_indices;
+#pod
+#pod This method updates the index files from the CPAN.
+#pod
+#pod =cut
 
 sub _fixed_mirrors {
   qw(
@@ -275,6 +426,14 @@ sub _install_indices {
   }
 }
 
+#pod =method mirror_file
+#pod
+#pod   $minicpan->mirror_file($path, $skip_if_present)
+#pod
+#pod This method will mirror the given file from the remote to the local mirror,
+#pod overwriting any existing file unless C<$skip_if_present> is true.
+#pod
+#pod =cut
 
 sub mirror_file {
   my ($self, $path, $skip_if_present, $arg) = @_;
@@ -337,6 +496,23 @@ sub mirror_file {
   }
 }
 
+#pod =begin devel
+#pod
+#pod =method _filter_module
+#pod
+#pod  next
+#pod    if $self->_filter_module({ module => $foo, version => $foo, path => $foo });
+#pod
+#pod This method holds the filter chain logic. C<update_mirror> takes an optional
+#pod set of filter parameters.  As C<update_mirror> encounters a distribution, it
+#pod calls this method to figure out whether or not it should be downloaded. The
+#pod user provided filters are taken into account. Returns 1 if the distribution is
+#pod filtered (to be skipped).  Returns 0 if the distribution is to not filtered
+#pod (not to be skipped).
+#pod
+#pod =end devel
+#pod
+#pod =cut
 
 sub __do_filter {
   my ($self, $filter, $file) = @_;
@@ -373,6 +549,17 @@ sub _filter_module {
   return 0;
 }
 
+#pod =method file_allowed
+#pod
+#pod   next unless $minicpan->file_allowed($filename);
+#pod
+#pod This method returns true if the given file is allowed to exist in the local
+#pod mirror, even if it isn't one of the required mirror files.
+#pod
+#pod By default, only dot-files are allowed.  If the C<exact_mirror> option is true,
+#pod all files are allowed.
+#pod
+#pod =cut
 
 sub file_allowed {
   my ($self, $file) = @_;
@@ -384,6 +571,24 @@ sub file_allowed {
   return (substr(File::Basename::basename($file), 0, 1) eq q{.}) ? 1 : 0;
 }
 
+#pod =method clean_unmirrored
+#pod
+#pod   $minicpan->clean_unmirrored;
+#pod
+#pod This method looks through the local mirror's files.  If it finds a file that
+#pod neither belongs in the mirror nor is allowed (see the C<file_allowed> method),
+#pod C<clean_file> is called on the file.
+#pod
+#pod If you set C<ignore_source_control> to a true value, then this doesn't clean
+#pod up files that belong to source control systems. Currently this ignores:
+#pod
+#pod 	.cvs .cvsignore
+#pod 	.svn .svnignore
+#pod 	.git .gitignore
+#pod
+#pod Send patches for other source control files that you would like to have added.
+#pod
+#pod =cut
 
 my %Source_control_files;
 BEGIN {
@@ -414,6 +619,14 @@ sub clean_unmirrored {
   }, $self->{local};
 }
 
+#pod =method clean_file
+#pod
+#pod   $minicpan->clean_file($filename);
+#pod
+#pod This method, called by C<clean_unmirrored>, deletes the named file.  It returns
+#pod true if the file is successfully unlinked.  Otherwise, it returns false.
+#pod
+#pod =cut
 
 sub clean_file {
   my ($self, $file) = @_;
@@ -428,6 +641,20 @@ sub clean_file {
   return 1;
 }
 
+#pod =method log_warn
+#pod
+#pod =method log
+#pod
+#pod =method log_debug
+#pod
+#pod   $minicpan->log($message);
+#pod
+#pod This will log (print) the given message unless the log level is too low.
+#pod
+#pod C<log>, which logs at the I<info> level, may also be called as C<trace> for
+#pod backward compatibility reasons.
+#pod
+#pod =cut
 
 sub log_level {
   return $_[0]->{log_level} if ref $_[0];
@@ -462,6 +689,16 @@ sub log_debug {
   $_[0]->log_unconditionally($_[1], $_[2]);
 }
 
+#pod =method read_config
+#pod
+#pod   my %config = CPAN::Mini->read_config(\%options);
+#pod
+#pod This routine returns a set of arguments that can be passed to CPAN::Mini's
+#pod C<new> or C<update_mirror> methods.  It will look for a file called
+#pod F<.minicpanrc> in the user's home directory as determined by
+#pod L<File::HomeDir|File::HomeDir>.
+#pod
+#pod =cut
 
 sub __homedir {
   my ($class) = @_;
@@ -542,6 +779,19 @@ sub read_config {
   return %config;
 }
 
+#pod =method config_file
+#pod
+#pod   my $config_file = CPAN::Mini->config_file( { options } );
+#pod
+#pod This routine returns the config file name. It first looks at for the
+#pod C<config_file> setting, then the C<CPAN_MINI_CONFIG> environment
+#pod variable, then the default F<~/.minicpanrc>, and finally the
+#pod F<CPAN/Mini/minicpan.conf>. It uses the first defined value it finds.
+#pod If the filename it selects does not exist, it returns false.
+#pod
+#pod OPTIONS is an optional hash reference of the C<CPAN::Mini> config hash.
+#pod
+#pod =cut
 
 sub config_file {
   my ($class, $options) = @_;
@@ -567,6 +817,18 @@ sub config_file {
   );
 }
 
+#pod =head2 remote_from
+#pod
+#pod   my $remote = CPAN::Mini->remote_from( $remote_from, $orig_remote, $quiet );
+#pod
+#pod This routine take an string argument and turn it into a method
+#pod call to handle to retrieve the a cpan mirror url from a source.
+#pod Currently supported methods:
+#pod
+#pod     cpan     - fetch the first mirror from your CPAN.pm config
+#pod     cpanplus - fetch the first mirror from your CPANPLUS.pm config
+#pod
+#pod =cut
 
 sub remote_from {
   my ( $class, $remote_from, $orig_remote, $quiet ) = @_;
@@ -584,6 +846,15 @@ sub remote_from {
   return $new_remote;
 }
 
+#pod =head2 remote_from_cpan
+#pod
+#pod   my $remote = CPAN::Mini->remote_from_cpan;
+#pod
+#pod This routine loads your CPAN.pm config and returns the first mirror in mirror
+#pod list.  You can set this as your default by setting remote_from:cpan in your
+#pod F<.minicpanrc> file.
+#pod
+#pod =cut
 
 sub remote_from_cpan {
   my ($self) = @_;
@@ -602,6 +873,15 @@ sub remote_from_cpan {
   return $CPAN::Config->{urllist}[0];
 }
 
+#pod =head2 remote_from_cpanplus
+#pod
+#pod   my $remote = CPAN::Mini->remote_from_cpanplus;
+#pod
+#pod This routine loads your CPANPLUS.pm config and returns the first mirror in
+#pod mirror list.  You can set this as your default by setting remote_from:cpanplus
+#pod in your F<.minicpanrc> file.
+#pod
+#pod =cut
 
 sub remote_from_cpanplus {
   my ($self) = @_;
@@ -622,6 +902,35 @@ sub remote_from_cpanplus {
   return $url_parts->{scheme} . "://" . $url_parts->{host} . ( $url_parts->{path} || '' );
 }
 
+#pod =head1 SEE ALSO
+#pod
+#pod Randal Schwartz's original article on minicpan, here:
+#pod
+#pod 	http://www.stonehenge.com/merlyn/LinuxMag/col42.html
+#pod
+#pod L<CPANPLUS::Backend>, which provides the C<local_mirror> method, which performs
+#pod the same task as this module.
+#pod
+#pod =head1 THANKS
+#pod
+#pod Thanks to David Dyck for letting me know about my stupid documentation errors.
+#pod
+#pod Thanks to Roy Fulbright for finding an obnoxious bug on Win32.
+#pod
+#pod Thanks to Shawn Sorichetti for fixing a stupid octal-number-as-string bug.
+#pod
+#pod Thanks to sungo for implementing the filters, so I can finally stop mirroring
+#pod bioperl, and Robert Rothenberg for suggesting adding coderef rules.
+#pod
+#pod Thanks to Adam Kennedy for noticing and complaining about a lot of stupid
+#pod little design decisions.
+#pod
+#pod Thanks to Michael Schwern and Jason Kohles, for pointing out missing
+#pod documentation.
+#pod
+#pod Thanks to David Golden for some important bugfixes and refactoring.
+#pod
+#pod =cut
 
 1;
 
@@ -637,7 +946,7 @@ CPAN::Mini - create a minimal mirror of CPAN
 
 =head1 VERSION
 
-version 1.111015
+version 1.111016
 
 =head1 SYNOPSIS
 
@@ -881,7 +1190,7 @@ true if the file is successfully unlinked.  Otherwise, it returns false.
 
   $minicpan->log($message);
 
-This will log (print) the given message unless the log level is too loo.
+This will log (print) the given message unless the log level is too low.
 
 C<log>, which logs at the I<info> level, may also be called as C<trace> for
 backward compatibility reasons.
